import Vue from 'vue'
import 'normalize.css/normalize.css' // A modern alternative to CSS resets
import moment from 'moment'
import './plugins'
import '@/styles/index.scss' // global css
import App from './App'
import store from './store'
import router from './router'
import permission from './directive/permission'
import '@/permission' // permission control
import Upload from '@/components/Upload/index'
import { download, handleTree } from '@/utils/common'
import Pagination from '@/components/Pagination'
import { uploadPublic } from '@/api/fileUploadPublic'
import { scrollToError } from '@/utils/common'
import Viewer from 'v-viewer'
import 'viewerjs/dist/viewer.css'
import axios from 'axios'
Vue.use(Viewer)
Vue.prototype.$axios = axios
Viewer.setDefaults({
  Options: {
    'inline': true, 'button': true, 'navbar': false, 'title': true,
    'toolbar': true, 'tooltip': true, 'movable': true, 'zoomable': true,
    'rotatable': true, 'scalable': true, 'transition': true, 'fullscreen': false,
    'keyboard': true, minZoomRatio: 0.50, maxZoomRatio: 150
  }
})
// 全局图片预览
import Preview from '@/components/imagePreivew/index'
Vue.use(Preview)

// 全局方法挂载
Vue.prototype.download = download
Vue.prototype.handleTree = handleTree
Vue.prototype.$uploadFile = uploadPublic
Vue.prototype.$scrollToFirstError = scrollToError
Vue.component('el-upload', Upload)
// set ElementUI lang to EN
Vue.prototype.$parseDate = (value, format) => {
  if (!value || value === '') {
    return '-'
  }
  return moment(value).format(format || 'YYYY-MM-DD HH:mm')
}
// 如果想要中文版 element-ui，按如下方式声明
Vue.config.productionTip = false
// 全局组件挂载
Vue.component('Pagination', Pagination)
// 全局日期转换过滤器 传格式/默认为YYYY-MM-DD HH:mm
Vue.filter('transformDateByFormat', (value, format) => {
  if (!value || value === '') {
    return '-'
  }
  if (new Date(value) == 'Invalid Date') { return '-' }
  return moment(value).format(format || 'YYYY-MM-DD HH:mm')
})

Vue.use(permission)

new Vue({
  el: '#app',
  router,
  store,
  render: h => h(App)
})
